@@ -15,7 +15,11 @@ class BatchJournal(DeactivableMixin, ModelSQL, ModelView):
 
     name = fields.Char('Name', required=True)
     account_journal = fields.Many2One('account.journal', 'Account Journal',
-            required=True)
+        required=True,
+        context={
+            'company': Eval('company', -1),
+            },
+        depends=['company'])
     currency = fields.Many2One('currency.currency', 'Currency', required=True)
     company = fields.Many2One('company.company', 'Company', required=True)
     account = fields.Many2One('account.account', "Account",
